import { Response } from 'express';
import { AuthRequest } from '../../../middleware/auth';
import { userService } from '../../../services/userService';

export async function getUsers(req: AuthRequest, res: Response): Promise<void> {
  try {
    // Проверка прав администратора
    if (!req.user?.permissions.isAdmin) {
      res.status(403).json({ error: 'Admin access required' });
      return
    }

    // Получение списка пользователей
    const users = await userService.getUsers();
    res.json(users);
  } catch {
    res.status(500).json({ error: 'Server error' });
  }
}

export async function updateUserPermissions(req: AuthRequest, res: Response): Promise<void> {
  try {
    // Проверка прав администратора
    if (!req.user?.permissions.isAdmin) {
      res.status(403).json({ error: 'Admin access required' });
      return
    }

    // Извлечение параметров из запроса
    const { id } = req.params;
    const { permissions } = req.body;

    // Обновление прав пользователя
    const user = await userService.updateUserPermissions(id, permissions);
    res.json(user);
  } catch {
    res.status(500).json({ error: 'Server error' });
  }
}